@@ -34,8 +34,8 @@ class HDF5IOHandlerImpl;
 class HDF5IOHandler : public AbstractIOHandler
 {
 public:
-    HDF5IOHandler(std::string const& path, AccessType);
-    virtual ~HDF5IOHandler() override;
+    HDF5IOHandler(std::string path, AccessType);
+    ~HDF5IOHandler() override;
 
     std::future< void > flush() override;
 
